# Table of Contents

- [portfolio-assessment-methodologies](<./portfolio-assessment-methodologies.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Portfolio Assessment Methodologies](<./Portfolio-Assessment-Methodologies.md>)
